pub struct DecodedEntity {
pub id: u32,
pub ifc_type: IfcType,
pub attributes: Arc<Vec<AttributeValue>>,
}Expand description
Decoded IFC entity. attributes is behind an Arc so cloning a
DecodedEntity (the decoder clones on every cache insert AND every cache
hit) is a refcount bump, not a deep clone of the attribute tree. Attributes
are never mutated after construction, so sharing is sound and byte-identical.
Fields
id: u32ifc_type: IfcTypeattributes: Arc<Vec<AttributeValue>>Implementations
Sourceimpl DecodedEntity
impl DecodedEntity
Sourcepub fn new(id: u32, ifc_type: IfcType, attributes: Vec<AttributeValue>) -> Self
pub fn new(id: u32, ifc_type: IfcType, attributes: Vec<AttributeValue>) -> Self
Create new decoded entity
Sourcepub fn get(&self, index: usize) -> Option<&AttributeValue>
pub fn get(&self, index: usize) -> Option<&AttributeValue>
Get attribute by index
Sourcepub fn get_string(&self, index: usize) -> Option<&str>
pub fn get_string(&self, index: usize) -> Option<&str>
Get string attribute
Sourcepub fn get_list(&self, index: usize) -> Option<&[AttributeValue]>
pub fn get_list(&self, index: usize) -> Option<&[AttributeValue]>
Get list attribute